==> FreeUSP-1.01.tgz: trcgp/usp/src/cmd/specal/globals.h <==
/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include "textern_key.h"
/* coloreditor changes */
EXTERN	int	xadd, yadd, len_k_xform, ncmplx;
EXTERN int ncmplx1, ncmplx2, ncmplx3, numpt, numpt1;
EXTERN int pixwidth1, pixwidth2, pixwidth3, can_hi1, can_hi2, can_hi3;
EXTERN int can_bias_x1, can_bias_x3, can_bias_y1, can_bias_y3;
/*.........added these so the 2-d freq stays valid..*/
EXTERN float freqi1,freqi2,freqi3;
EXTERN	float	*spec2d;
EXTERN	int	nds;
EXTERN	float	*amp, *hold2d;
EXTERN	int	factor, xpos, ypos, xadd, yadd;
EXTERN	int	pw1, ph1, pws1, phs1;
EXTERN GC gclocal ;
/* end of coloreditor changes */
EXTERN void fileselCB(), fileact();
EXTERN void get_parms();
EXTERN void quit_callback();
EXTERN void display_it(), display_it2();
EXTERN Widget nhead[4];
EXTERN Widget phead[4];
EXTERN int 	spec_type, spec_flag;
EXTERN int 	phase_type;
EXTERN int		traces_per_inch;
EXTERN int		maxovlp;
EXTERN int		s_record, e_record;
EXTERN int num_files;
EXTERN int pix_per_trace;
EXTERN int nss, ns, ntr, nrec, smpint;
EXTERN float	asmpint;
EXTERN	int	lntr;
EXTERN int pixwidth, can_bias_x, can_bias_y;
EXTERN int can_hi, iselect;
EXTERN int kselect;
EXTERN int st_rec, end_rec, ntrace, ntracea, ntracep;
EXTERN int ph_off, ph_offset;
EXTERN int depth;
EXTERN float maxval, psint,pix_per_sample, *data;
EXTERN float datamin, datamax;
EXTERN float   inches_per_second;
EXTERN float	scalr;
/*EXTERN char	*input_file;*/
/* 070991 mam */
/*EXTERN	char	*old_input_file;*/
EXTERN	int	luin;
EXTERN	int	old_srec, old_strc;
EXTERN	int	krec, ktrc;
EXTERN	int	new_open;
/* .......... */
EXTERN char *files[MAX_FILES];
EXTERN char *files2[10];
EXTERN char *filesp[MAX_FILES];
EXTERN Widget trinc, gt50;
EXTERN Widget parm_panel,parm_panel_sw,parm_panel_dialog;
EXTERN Widget ktoo;
EXTERN Widget toplevel, bboard;
EXTERN Widget bboard2, bboard3;
EXTERN Widget buttona1, buttona2, buttona3;
EXTERN Widget buttona4, buttona5;
EXTERN Widget buttonb1, buttonb2;
EXTERN Widget button4, rowcol4, rowcol3;
EXTERN Widget button2;
EXTERN Widget labels[20], texts[20];
EXTERN Widget draw_area, view_window;
EXTERN Widget nitems[MAX_FILES + 2];
EXTERN Widget kitems[12];
EXTERN Widget nitemsp[MAX_FILES + 2];
EXTERN Widget kitems[12];
EXTERN Widget kitemsp[12];
EXTERN Widget pop_up2, pop_up3, pop_up2p, pop_up_amp, pop_up_ph;
EXTERN Widget pop_up_2d, pop_up2d;
EXTERN Widget slider1;
/* 4/4/91 mam */
EXTERN Widget errmsg;
EXTERN Display *display;
EXTERN XID xid1;
/* added 030691 mam */
EXTERN XID xid;
EXTERN GC gcs;
EXTERN XGCValues gcsvals;
EXTERN Pixmap copypix;
EXTERN Pixmap pixmap1[MAX_FILES], pixmap3[MAX_FILES];
/*EXTERN Pixmap pixmap1[MAX_FILES], pixmap2[1], pixmap3[MAX_FILES];*/
EXTERN XImage *new_image;
EXTERN void draw_it();

EXTERN Lfont pl_font, num_font, letter_font;
/* added 2-7-91 mam */
EXTERN	int	trc_incr, st_win, end_win, s_trace, st_trc, e_trace, end_trc;
/* added 2-19-91 nan */
EXTERN XtIntervalId	tid, oldtid;
EXTERN void animation();
/* added 022091 mam */
EXTERN unsigned long	atime;
EXTERN	void	do_2d();
/*EXTERN	Pixmap	do_2d();*/

EXTERN Widget toplevel, odometer, message, error_dialog;

EXTERN Display *display ;
EXTERN GC gc, gc_rubber, gc_odometer ;
EXTERN Pixel black, white, hycolor, apcolor, npcolor ;
EXTERN XGCValues gcvals ;

EXTERN Lfont num_font, letter_font ;
EXTERN int line_width;
EXTERN Widget zoomsw, zoomdraw, zhsb, zvsb;
EXTERN Widget vvsb, vhsb;
EXTERN int vvmin, vvmax, vhmin, vhmax;
EXTERN int zvmin, zvmax, zhmin, zhmax;
EXTERN Widget zform;
EXTERN Window zwin;
EXTERN int copy_pix;
EXTERN int xwidth, xheight;
EXTERN int zoomTF, zoomx, zoomy, zoomwid, zoomht;
EXTERN Widget set_parm, redisp1, redisp2, redisp3;
EXTERN float fscale;
EXTERN float freq_incr, fnyqst;
EXTERN float freqi;
EXTERN Widget ztexts[2];
EXTERN float *artap, *srtap;
/*.........save old parameters for resetting parm screen......*/
EXTERN int old_spec_type,old_phase_type,old_ph_offset,old_s_rec,old_e_rec,
	old_s_tr,old_e_tr,old_tr_inc,old_s_win,old_e_win,old_parms;
/*............................................................*/
/* EXTERN Desc2d Info2d[10];*/
/* EXTERN int iptcc;*/

==> FreeUSP-1.02.tgz: trcgp/usp/src/cmd/specal/globals.h <==
/***********************************************************************
 *                copyright 2001, Amoco Production Company             *
 *                            All Rights Reserved                      *
 *                    an affiliate of BP America Inc.                  *
 ***********************************************************************/
#include "textern_key.h"
/* coloreditor changes */
EXTERN	int	xadd, yadd, len_k_xform, ncmplx;
EXTERN int ncmplx1, ncmplx2, ncmplx3, numpt, numpt1;
EXTERN int pixwidth1, pixwidth2, pixwidth3, can_hi1, can_hi2, can_hi3;
EXTERN int can_bias_x1, can_bias_x3, can_bias_y1, can_bias_y3;
/*.........added these so the 2-d freq stays valid..*/
EXTERN float freqi1,freqi2,freqi3;
EXTERN	float	*spec2d;
EXTERN	int	nds;
EXTERN	float	*amp, *hold2d;
EXTERN	int	factor, xpos, ypos, xadd, yadd;
EXTERN	int	pw1, ph1, pws1, phs1;
EXTERN GC gclocal ;
/* end of coloreditor changes */
EXTERN void fileselCB(), fileact();
EXTERN void get_parms();
EXTERN void quit_callback();
EXTERN void display_it(), display_it2();
EXTERN Widget nhead[4];
EXTERN Widget phead[4];
EXTERN int 	spec_type, spec_flag;
EXTERN int 	phase_type;
EXTERN int		traces_per_inch;
EXTERN int		maxovlp;
EXTERN int		s_record, e_record;
EXTERN int num_files;
EXTERN int pix_per_trace;
EXTERN int nss, ns, ntr, nrec, smpint;
EXTERN float	asmpint, unitsc;
EXTERN	int	lntr;
EXTERN int pixwidth, can_bias_x, can_bias_y;
EXTERN int can_hi, iselect;
EXTERN int kselect;
EXTERN int st_rec, end_rec, ntrace, ntracea, ntracep;
EXTERN int ph_off, ph_offset;
EXTERN int depth;
EXTERN float maxval, psint,pix_per_sample, *data;
EXTERN float datamin, datamax;
EXTERN float   inches_per_second;
EXTERN float	scalr;
/*EXTERN char	*input_file;*/
/* 070991 mam */
/*EXTERN	char	*old_input_file;*/
EXTERN	int	luin;
EXTERN	int	old_srec, old_strc;
EXTERN	int	krec, ktrc;
EXTERN	int	new_open;
/* .......... */
EXTERN char *files[MAX_FILES];
EXTERN char *files2[10];
EXTERN char *filesp[MAX_FILES];
EXTERN Widget trinc, gt50;
EXTERN Widget parm_panel,parm_panel_sw,parm_panel_dialog;
EXTERN Widget ktoo;
EXTERN Widget toplevel, bboard;
EXTERN Widget bboard2, bboard3;
EXTERN Widget buttona1, buttona2, buttona3;
EXTERN Widget buttona4, buttona5;
EXTERN Widget buttonb1, buttonb2;
EXTERN Widget button4, rowcol4, rowcol3;
EXTERN Widget button2;
EXTERN Widget labels[20], texts[20];
EXTERN Widget draw_area, view_window;
EXTERN Widget nitems[MAX_FILES + 2];
EXTERN Widget kitems[12];
EXTERN Widget nitemsp[MAX_FILES + 2];
EXTERN Widget kitems[12];
EXTERN Widget kitemsp[12];
EXTERN Widget pop_up2, pop_up3, pop_up2p, pop_up_amp, pop_up_ph;
EXTERN Widget pop_up_2d, pop_up2d;
EXTERN Widget slider1;
/* 4/4/91 mam */
EXTERN Widget errmsg;
EXTERN Display *display;
EXTERN XID xid1;
/* added 030691 mam */
EXTERN XID xid;
EXTERN GC gcs;
EXTERN XGCValues gcsvals;
EXTERN Pixmap copypix;
EXTERN Pixmap pixmap1[MAX_FILES], pixmap3[MAX_FILES];
/*EXTERN Pixmap pixmap1[MAX_FILES], pixmap2[1], pixmap3[MAX_FILES];*/
EXTERN XImage *new_image;
EXTERN void draw_it();

EXTERN Lfont pl_font, num_font, letter_font;
/* added 2-7-91 mam */
EXTERN	int	trc_incr, st_win, end_win, s_trace, st_trc, e_trace, end_trc;
/* added 2-19-91 nan */
EXTERN XtIntervalId	tid, oldtid;
EXTERN void animation();
/* added 022091 mam */
EXTERN unsigned long	atime;
EXTERN	void	do_2d();
/*EXTERN	Pixmap	do_2d();*/

EXTERN Widget toplevel, odometer, message, error_dialog;

EXTERN Display *display ;
EXTERN GC gc, gc_rubber, gc_odometer ;
EXTERN Pixel black, white, hycolor, apcolor, npcolor ;
EXTERN XGCValues gcvals ;

EXTERN Lfont num_font, letter_font ;
EXTERN int line_width;
EXTERN Widget zoomsw, zoomdraw, zhsb, zvsb;
EXTERN Widget vvsb, vhsb;
EXTERN int vvmin, vvmax, vhmin, vhmax;
EXTERN int zvmin, zvmax, zhmin, zhmax;
EXTERN Widget zform;
EXTERN Window zwin;
EXTERN int copy_pix;
EXTERN int xwidth, xheight;
EXTERN int zoomTF, zoomx, zoomy, zoomwid, zoomht;
EXTERN Widget set_parm, redisp1, redisp2, redisp3;
EXTERN float fscale;
EXTERN float freq_incr, fnyqst;
EXTERN float freqi;
EXTERN Widget ztexts[2];
EXTERN float *artap, *srtap;
/*.........save old parameters for resetting parm screen......*/
EXTERN int old_spec_type,old_phase_type,old_ph_offset,old_s_rec,old_e_rec,
	old_s_tr,old_e_tr,old_tr_inc,old_s_win,old_e_win,old_parms;
/*............................................................*/
/* EXTERN Desc2d Info2d[10];*/
/* EXTERN int iptcc;*/
